from functools import wraps

from flask import request, jsonify, current_app

from jsonschema import validate
from jsonschema.exceptions import ValidationError


def validate_json(f):
    @wraps(f)
    def wrapper(*args, **kw):
        try:
            request.get_json()
        except Exception:
            msg = "payload must be a valid json"
            return jsonify({"error": msg}), 400
        return f(*args, **kw)
    return wrapper


def validate_schema(schema):
    def decorator(f):
        @wraps(f)
        def wrapper(*args, **kw):
            try:
                validate(request.json, schema)
            except ValidationError as e:
                return jsonify({"error": e.message}), 400
            return f(*args, **kw)
        return wrapper
    return decorator



from distutils.core import setup
from setuptools import find_packages


def readme():
    with open('README.md') as f:
        return f.read()

setup(
  name = 'flask-check-json', 
  packages=find_packages(exclude=['tests.*', 'tests']),
  version = '0.1.7',
  license='MIT',
  description = 'JSON Validator',
  long_description=readme(),
  long_description_content_type="text/markdown",
  author = 'Ercy Moreira Neto',
  author_email = 'ercym.neto@gmail.com',
  url = 'https://github.com/panda-coder/flask-check-json',
  download_url = 'https://github.com/panda-coder/flask-check-json',
  keywords = ['json'],
  install_requires=[
        'flask>=1.0.2',
        'jsonschema>=3.0.1'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Framework :: Flask',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6'
  ],
)


# Flask imports
from flask import request, abort, make_response, jsonify

# JSON SChema Imports
from jsonschema import validate
from jsonschema.exceptions import ValidationError


def validate_json(f):
    # Validate the json
    try:
        request.get_json()
    except Exception:
        msg = "payload must be a valid json"
        return abort(400, {"error": msg})


def validate_schema(schema=None, force=False, data=None):
    if not data:
        # Validate the schema of the json
        data = request.get_json(force=force)

    if data is None:
        return abort(400, 'Failed to decode JSON object')

    try:
        validate(data, schema)
    except ValidationError as e:
        return abort(make_response(jsonify({"status": "400", "message": e.message}), 400))
